package com.agilecontrol.ucenter.util;

import cn.hutool.http.HttpUtil;
import com.agilecontrol.common.util.utils.JsonUtils;
import com.agilecontrol.nea.core.util.ConfigValues;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.annotations.ApiModelProperty;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import javax.annotation.Nullable;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class FilaHelper {

   private static final Logger log = LoggerFactory.getLogger(FilaHelper.class);
   public static final String ENV_HOST_KEY = "env.fila.iam.host";
   public static final String ENV_CLIENT_KEY = "env.fila.iam.clientId";
   public static final String ENV_SECURE_KEY = "env.fila.iam.clientSecret";
   public static final String ENV_REDIRECT_KEY = "env.fila.iam.redirectUrl";
   @ApiModelProperty("FILA IAM 主接口地址")
   private String iamHost = "http://authtest.anta.com:8080/oauth2.0";
   @ApiModelProperty("FILA IAM CK")
   private String clientId = "100051";
   @ApiModelProperty("FILA IAM SK")
   private String clientSecret = "59ddf617389111ed9c22005056a57cf5";
   @ApiModelProperty("IAM 回调地址")
   private String redirectUrl = "http://office.lifecycle.cn:43810/svr/portal/user/iam/leap";
   private int countDown = '훘';
   private String code;
   private String chargeTokenUri = "/accessToken";
   private String chargeUserUri = "/profile";


   public FilaHelper() {
      this.iamHost = ConfigValues.get("env.fila.iam.host", this.iamHost);
      this.clientId = ConfigValues.get("env.fila.iam.clientId", this.clientId);
      this.clientSecret = ConfigValues.get("env.fila.iam.clientSecret", this.clientSecret);
      this.redirectUrl = ConfigValues.get("env.fila.iam.redirectUrl", this.redirectUrl);
   }

   public FilaHelper(String iamHost, String clientId, String clientSecret, String redirectUrl) {
      this.iamHost = iamHost;
      this.clientId = clientId;
      this.clientSecret = clientSecret;
      this.redirectUrl = redirectUrl;
   }

   public String getIamHost() {
      return this.iamHost;
   }

   public void setIamHost(String iamHost) {
      this.iamHost = iamHost;
   }

   public String getClientId() {
      return this.clientId;
   }

   public void setClientId(String clientId) {
      this.clientId = clientId;
   }

   public String getClientSecret() {
      return this.clientSecret;
   }

   public void setClientSecret(String clientSecret) {
      this.clientSecret = clientSecret;
   }

   public String getRedirectUrl() {
      return this.redirectUrl;
   }

   public void setRedirectUrl(String redirectUrl) {
      this.redirectUrl = redirectUrl;
   }

   public int getCountDown() {
      return this.countDown;
   }

   public void setCountDown(int countDown) {
      this.countDown = countDown;
   }

   public void setCode(String code) {
      this.code = code;
   }

   public String getCode(String code) {
      return this.code;
   }

   public String chargeToken(String code) {
      this.code = code;
      String chargeUrl = this.iamHost + this.chargeTokenUri;
      HashMap param = new HashMap();
      param.put("grant_type", "authorization_code");
      param.put("client_id", this.clientId);
      param.put("client_secret", this.clientSecret);
      param.put("code", code);
      param.put("redirect_uri", this.redirectUrl);
      String resp = HttpUtil.get(chargeUrl, param, this.countDown);
      log.debug("charge token by iam code, url={}, request.param={}, response={}: ", new Object[]{chargeUrl, JsonUtils.toJson(param), resp});
      if(StringUtils.isNotBlank(resp)) {
         FilaHelper.IAMTokenResp iamTokenResp = (FilaHelper.IAMTokenResp)JsonUtils.parse(resp, FilaHelper.IAMTokenResp.class);
         if(iamTokenResp != null) {
            if(iamTokenResp.isSuccess()) {
               return iamTokenResp.getAccess_token();
            }

            log.warn("charge token with error: {}", iamTokenResp.getMessage());
         }
      }

      return "";
   }

   public FilaHelper.IAMUserAttribute chargeUser(@Nullable String accessToken) {
      String chargeUrl = this.iamHost + this.chargeUserUri;
      HashMap param = new HashMap();
      param.put("access_token", accessToken);
      String resp = HttpUtil.get(chargeUrl, param, this.countDown);
      log.info("charge user by iam token, url={}, request.param={}, response={}. ", new Object[]{chargeUrl, JsonUtils.toJson(param), resp});
      if(StringUtils.isNotBlank(resp)) {
         FilaHelper.IAMUserResp iamUserResp = (FilaHelper.IAMUserResp)JsonUtils.parse(resp, FilaHelper.IAMUserResp.class);
         if(iamUserResp != null && iamUserResp.getAttributes() != null) {
            return iamUserResp.getAttributes();
         }

         log.warn("charge token with error: undefined iam user info");
      }

      return new FilaHelper.IAMUserAttribute();
   }

   public String getLogoutUrl() {
      String ret = this.getBaseUrl(this.iamHost);
      ret = ret + "/logout?service=" + this.getBaseUrl(this.redirectUrl);
      return ret;
   }

   private String getBaseUrl(String url) {
      String ret = "";
      URL redirect = null;

      try {
         redirect = new URL(url);
      } catch (MalformedURLException var9) {
         log.warn("URL解析出现异常：url = {}, error = {}", url, var9.getMessage());
      }

      int port = redirect.getPort();
      String agreement = redirect.getProtocol();
      String serverName = redirect.getHost();
      String portStr = "";
      String formatter = "%s://%s%s";
      if(port != 80) {
         portStr = portStr + ":" + port;
      }

      return String.format(formatter, new Object[]{agreement, serverName, portStr});
   }

   public static void main(String[] args) {
      String json = "{\n    \"service\":\"http://office.lifecycle.cn:43810/svr/portal/user/iam/leap\",\n    \"attributes\":{\n        \"accountTypeFlag\":1,\n        \"email\":\"\",\n        \"employeeId\":\"2022041745\",\n        \"fullName\":\"毛海文\",\n        \"id\":4249,\n        \"loginName\":\"2022041745\",\n        \"mobile\":\"\",\n        \"name\":\"毛海文\",\n        \"oauthClientId\":\"100051\",\n        \"org.apereo.cas.authentication.Authentication\":{\n            \"authenticationDate\":\"2023-06-08T06:43:54.857658Z\",\n            \"principal\":{\n                \"@class\":\"org.apereo.cas.authentication.principal.SimplePrincipal\",\n                \"id\":\"2022041745\",\n                \"attributes\":{\n                    \"accountTypeFlag\":1,\n                    \"email\":\"\",\n                    \"employeeId\":\"2022041745\",\n                    \"fullName\":\"毛海文\",\n                    \"id\":4249,\n                    \"loginName\":\"2022041745\",\n                    \"mobile\":\"\",\n                    \"name\":\"毛海文\",\n                    \"organizationId\":\"0\",\n                    \"organizationName\":\"\",\n                    \"privilegeFlag\":0,\n                    \"staffInfoId\":5292,\n                    \"staffNo\":\"2022041745\",\n                    \"userTypeFlag\":1\n                }\n            },\n            \"credentials\":{\n                \"@class\":\"org.apereo.cas.authentication.metadata.BasicCredentialMetaData\",\n                \"id\":\"2022041745\",\n                \"credentialClass\":\"com.anta.cas.entity.credential.IamUsernamePasswordCredential\",\n                \"properties\":{\n                    \"UserAgent\":\"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36\",\n                    \"GeoLocation\":{\n\n                    }\n                }\n            },\n            \"attributes\":{\n                \"credentialType\":\"IamUsernamePasswordCredential\",\n                \"clientIpAddress\":\"10.250.4.1\",\n                \"authenticationDate\":1686206634,\n                \"authenticationMethod\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                \"successfulAuthenticationHandlers\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                \"serverIpAddress\":\"10.250.3.34\",\n                \"userAgent\":\"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36\"\n            },\n            \"successes\":{\n                \"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\":{\n                    \"@class\":\"org.apereo.cas.authentication.DefaultAuthenticationHandlerExecutionResult\",\n                    \"handlerName\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                    \"credentialMetaData\":{\n                        \"@class\":\"org.apereo.cas.authentication.metadata.BasicCredentialMetaData\",\n                        \"id\":\"2022041745\",\n                        \"credentialClass\":\"com.anta.cas.entity.credential.IamUsernamePasswordCredential\"\n                    },\n                    \"principal\":{\n                        \"@class\":\"org.apereo.cas.authentication.principal.SimplePrincipal\",\n                        \"id\":\"2022041745\",\n                        \"attributes\":{\n                            \"accountTypeFlag\":1,\n                            \"email\":\"\",\n                            \"employeeId\":\"2022041745\",\n                            \"fullName\":\"毛海文\",\n                            \"id\":4249,\n                            \"loginName\":\"2022041745\",\n                            \"mobile\":\"\",\n                            \"name\":\"毛海文\",\n                            \"organizationId\":\"0\",\n                            \"organizationName\":\"\",\n                            \"privilegeFlag\":0,\n                            \"staffInfoId\":5292,\n                            \"staffNo\":\"2022041745\",\n                            \"userTypeFlag\":1\n                        }\n                    }\n                }\n            }\n        },\n        \"org.apereo.cas.services.RegisteredService\":{\n            \"serviceId\":\"http(.*)fomsuat.fila-china.com.cn(.*)|http(.*)foms.fila-china.com.cn(.*)|http(.*)office.lifecycle.cn(.*)|http(.*)localhost(.*)\",\n            \"name\":\"FILA订单管理系统\",\n            \"id\":53,\n            \"description\":\"FILA订单管理系统\",\n            \"attributeReleasePolicy\":{\n                \"@class\":\"org.apereo.cas.services.ReturnAllAttributeReleasePolicy\"\n            },\n            \"clientSecret\":\"59ddf617389111ed9c22005056a57cf5\",\n            \"clientId\":\"100051\",\n            \"bypassApprovalPrompt\":true,\n            \"generateRefreshToken\":true,\n            \"supportedResponseTypes\":[\n                \"code\",\n                \"token\"\n            ]\n        },\n        \"org.apereo.cas.ticket.TicketGrantingTicket\":\"TGT-118--efbIp3cLxnb9gyA5S29f4UNIMgsUq-FhVRgm--KGcdVF8uJLun1HZZm4vyV8Tw6iB0-cas-overlay-cfff58d9d-tqsxj\",\n        \"org.apereo.cas.validation.Assertion\":{\n            \"primaryAuthentication\":{\n                \"@class\":\"org.apereo.cas.authentication.DefaultAuthentication\",\n                \"authenticationDate\":\"2023-06-08T06:43:54.857658Z\",\n                \"principal\":{\n                    \"@class\":\"org.apereo.cas.authentication.principal.SimplePrincipal\",\n                    \"id\":\"2022041745\",\n                    \"attributes\":{\n                        \"accountTypeFlag\":1,\n                        \"email\":\"\",\n                        \"employeeId\":\"2022041745\",\n                        \"fullName\":\"毛海文\",\n                        \"id\":4249,\n                        \"loginName\":\"2022041745\",\n                        \"mobile\":\"\",\n                        \"name\":\"毛海文\",\n                        \"organizationId\":\"0\",\n                        \"organizationName\":\"\",\n                        \"privilegeFlag\":0,\n                        \"staffInfoId\":5292,\n                        \"staffNo\":\"2022041745\",\n                        \"userTypeFlag\":1\n                    }\n                },\n                \"credentials\":{\n                    \"@class\":\"org.apereo.cas.authentication.metadata.BasicCredentialMetaData\",\n                    \"id\":\"2022041745\",\n                    \"credentialClass\":\"com.anta.cas.entity.credential.IamUsernamePasswordCredential\",\n                    \"properties\":{\n                        \"UserAgent\":\"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36\",\n                        \"GeoLocation\":{\n\n                        }\n                    }\n                },\n                \"attributes\":{\n                    \"credentialType\":\"IamUsernamePasswordCredential\",\n                    \"clientIpAddress\":\"10.250.4.1\",\n                    \"authenticationDate\":1686206634,\n                    \"authenticationMethod\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                    \"successfulAuthenticationHandlers\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                    \"serverIpAddress\":\"10.250.3.34\",\n                    \"userAgent\":\"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36\",\n                    \"isFromNewLogin\":false,\n                    \"longTermAuthenticationRequestTokenUsed\":false\n                },\n                \"successes\":{\n                    \"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\":{\n                        \"@class\":\"org.apereo.cas.authentication.DefaultAuthenticationHandlerExecutionResult\",\n                        \"handlerName\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                        \"credentialMetaData\":{\n                            \"@class\":\"org.apereo.cas.authentication.metadata.BasicCredentialMetaData\",\n                            \"id\":\"2022041745\",\n                            \"credentialClass\":\"com.anta.cas.entity.credential.IamUsernamePasswordCredential\"\n                        },\n                        \"principal\":{\n                            \"@class\":\"org.apereo.cas.authentication.principal.SimplePrincipal\",\n                            \"id\":\"2022041745\",\n                            \"attributes\":{\n                                \"accountTypeFlag\":1,\n                                \"email\":\"\",\n                                \"employeeId\":\"2022041745\",\n                                \"fullName\":\"毛海文\",\n                                \"id\":4249,\n                                \"loginName\":\"2022041745\",\n                                \"mobile\":\"\",\n                                \"name\":\"毛海文\",\n                                \"organizationId\":\"0\",\n                                \"organizationName\":\"\",\n                                \"privilegeFlag\":0,\n                                \"staffInfoId\":5292,\n                                \"staffNo\":\"2022041745\",\n                                \"userTypeFlag\":1\n                            }\n                        }\n                    }\n                }\n            },\n            \"originalAuthentication\":{\n                \"@class\":\"org.apereo.cas.authentication.DefaultAuthentication\",\n                \"authenticationDate\":\"2023-06-08T06:43:54.857658Z\",\n                \"principal\":{\n                    \"@class\":\"org.apereo.cas.authentication.principal.SimplePrincipal\",\n                    \"id\":\"2022041745\",\n                    \"attributes\":{\n                        \"accountTypeFlag\":1,\n                        \"email\":\"\",\n                        \"employeeId\":\"2022041745\",\n                        \"fullName\":\"毛海文\",\n                        \"id\":4249,\n                        \"loginName\":\"2022041745\",\n                        \"mobile\":\"\",\n                        \"name\":\"毛海文\",\n                        \"organizationId\":\"0\",\n                        \"organizationName\":\"\",\n                        \"privilegeFlag\":0,\n                        \"staffInfoId\":5292,\n                        \"staffNo\":\"2022041745\",\n                        \"userTypeFlag\":1\n                    }\n                },\n                \"credentials\":{\n                    \"@class\":\"org.apereo.cas.authentication.metadata.BasicCredentialMetaData\",\n                    \"id\":\"2022041745\",\n                    \"credentialClass\":\"com.anta.cas.entity.credential.IamUsernamePasswordCredential\",\n                    \"properties\":{\n                        \"UserAgent\":\"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36\",\n                        \"GeoLocation\":{\n\n                        }\n                    }\n                },\n                \"attributes\":{\n                    \"credentialType\":\"IamUsernamePasswordCredential\",\n                    \"clientIpAddress\":\"10.250.4.1\",\n                    \"authenticationDate\":1686206634,\n                    \"authenticationMethod\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                    \"successfulAuthenticationHandlers\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                    \"serverIpAddress\":\"10.250.3.34\",\n                    \"userAgent\":\"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36\"\n                },\n                \"successes\":{\n                    \"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\":{\n                        \"@class\":\"org.apereo.cas.authentication.DefaultAuthenticationHandlerExecutionResult\",\n                        \"handlerName\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                        \"credentialMetaData\":{\n                            \"@class\":\"org.apereo.cas.authentication.metadata.BasicCredentialMetaData\",\n                            \"id\":\"2022041745\",\n                            \"credentialClass\":\"com.anta.cas.entity.credential.IamUsernamePasswordCredential\"\n                        },\n                        \"principal\":{\n                            \"@class\":\"org.apereo.cas.authentication.principal.SimplePrincipal\",\n                            \"id\":\"2022041745\",\n                            \"attributes\":{\n                                \"accountTypeFlag\":1,\n                                \"email\":\"\",\n                                \"employeeId\":\"2022041745\",\n                                \"fullName\":\"毛海文\",\n                                \"id\":4249,\n                                \"loginName\":\"2022041745\",\n                                \"mobile\":\"\",\n                                \"name\":\"毛海文\",\n                                \"organizationId\":\"0\",\n                                \"organizationName\":\"\",\n                                \"privilegeFlag\":0,\n                                \"staffInfoId\":5292,\n                                \"staffNo\":\"2022041745\",\n                                \"userTypeFlag\":1\n                            }\n                        }\n                    }\n                }\n            },\n            \"chainedAuthentications\":{\n                \"@class\":\"org.apereo.cas.authentication.DefaultAuthentication\",\n                \"authenticationDate\":\"2023-06-08T06:43:54.857658Z\",\n                \"principal\":{\n                    \"@class\":\"org.apereo.cas.authentication.principal.SimplePrincipal\",\n                    \"id\":\"2022041745\",\n                    \"attributes\":{\n                        \"accountTypeFlag\":1,\n                        \"email\":\"\",\n                        \"employeeId\":\"2022041745\",\n                        \"fullName\":\"毛海文\",\n                        \"id\":4249,\n                        \"loginName\":\"2022041745\",\n                        \"mobile\":\"\",\n                        \"name\":\"毛海文\",\n                        \"organizationId\":\"0\",\n                        \"organizationName\":\"\",\n                        \"privilegeFlag\":0,\n                        \"staffInfoId\":5292,\n                        \"staffNo\":\"2022041745\",\n                        \"userTypeFlag\":1\n                    }\n                },\n                \"credentials\":{\n                    \"@class\":\"org.apereo.cas.authentication.metadata.BasicCredentialMetaData\",\n                    \"id\":\"2022041745\",\n                    \"credentialClass\":\"com.anta.cas.entity.credential.IamUsernamePasswordCredential\",\n                    \"properties\":{\n                        \"UserAgent\":\"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36\",\n                        \"GeoLocation\":{\n\n                        }\n                    }\n                },\n                \"attributes\":{\n                    \"credentialType\":\"IamUsernamePasswordCredential\",\n                    \"clientIpAddress\":\"10.250.4.1\",\n                    \"authenticationDate\":1686206634,\n                    \"authenticationMethod\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                    \"successfulAuthenticationHandlers\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                    \"serverIpAddress\":\"10.250.3.34\",\n                    \"userAgent\":\"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36\"\n                },\n                \"successes\":{\n                    \"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\":{\n                        \"@class\":\"org.apereo.cas.authentication.DefaultAuthenticationHandlerExecutionResult\",\n                        \"handlerName\":\"com.anta.cas.config.action.IamAuthenticationEventExecutionPlanConfiguration\",\n                        \"credentialMetaData\":{\n                            \"@class\":\"org.apereo.cas.authentication.metadata.BasicCredentialMetaData\",\n                            \"id\":\"2022041745\",\n                            \"credentialClass\":\"com.anta.cas.entity.credential.IamUsernamePasswordCredential\"\n                        },\n                        \"principal\":{\n                            \"@class\":\"org.apereo.cas.authentication.principal.SimplePrincipal\",\n                            \"id\":\"2022041745\",\n                            \"attributes\":{\n                                \"accountTypeFlag\":1,\n                                \"email\":\"\",\n                                \"employeeId\":\"2022041745\",\n                                \"fullName\":\"毛海文\",\n                                \"id\":4249,\n                                \"loginName\":\"2022041745\",\n                                \"mobile\":\"\",\n                                \"name\":\"毛海文\",\n                                \"organizationId\":\"0\",\n                                \"organizationName\":\"\",\n                                \"privilegeFlag\":0,\n                                \"staffInfoId\":5292,\n                                \"staffNo\":\"2022041745\",\n                                \"userTypeFlag\":1\n                            }\n                        }\n                    }\n                }\n            },\n            \"service\":{\n                \"@class\":\"org.apereo.cas.authentication.principal.SimpleWebApplicationServiceImpl\",\n                \"id\":\"http://office.lifecycle.cn:43810/svr/portal/user/iam/leap\",\n                \"originalUrl\":\"http://office.lifecycle.cn:43810/svr/portal/user/iam/leap\",\n                \"principal\":\"2022041745\",\n                \"source\":\"service\",\n                \"format\":\"XML\",\n                \"attributes\":{\n                    \"service\":\"http://authtest.anta.com:8080/oauth2.0/callbackAuthorize?client_id=100051&amp;redirect_uri=http%3A%2F%2Foffice.lifecycle.cn%3A43810%2Fsvr%2Fportal%2Fuser%2Fiam%2Fleap&amp;response_type=code&amp;client_name=CasOAuthClient\",\n                    \"response_type\":\"code\",\n                    \"redirect_uri\":\"http://office.lifecycle.cn:43810/svr/portal/user/iam/leap\",\n                    \"client_name\":\"CasOAuthClient\",\n                    \"client_id\":\"100051\"\n                }\n            },\n            \"registeredService\":{\n                \"@class\":\"org.apereo.cas.support.oauth.services.OAuthRegisteredService\",\n                \"serviceId\":\"http(.*)fomsuat.fila-china.com.cn(.*)|http(.*)foms.fila-china.com.cn(.*)|http(.*)office.lifecycle.cn(.*)|http(.*)localhost(.*)\",\n                \"name\":\"FILA订单管理系统\",\n                \"id\":53,\n                \"description\":\"FILA订单管理系统\",\n                \"attributeReleasePolicy\":{\n                    \"@class\":\"org.apereo.cas.services.ReturnAllAttributeReleasePolicy\"\n                },\n                \"clientSecret\":\"59ddf617389111ed9c22005056a57cf5\",\n                \"clientId\":\"100051\",\n                \"bypassApprovalPrompt\":true,\n                \"generateRefreshToken\":true,\n                \"supportedResponseTypes\":[\n                    \"code\",\n                    \"token\"\n                ]\n            },\n            \"context\":{\n                \"org.apereo.cas.ticket.TicketGrantingTicket\":\"TGT-118--efbIp3cLxnb9gyA5S29f4UNIMgsUq-FhVRgm--KGcdVF8uJLun1HZZm4vyV8Tw6iB0-cas-overlay-cfff58d9d-tqsxj\"\n            }\n        },\n        \"organizationId\":\"0\",\n        \"organizationName\":\"\",\n        \"privilegeFlag\":0,\n        \"staffInfoId\":5292,\n        \"staffNo\":\"2022041745\",\n        \"userTypeFlag\":1\n    },\n    \"id\":\"2022041745\",\n    \"client_id\":\"100051\"\n}";
      FilaHelper.IAMUserResp iamUserResp = (FilaHelper.IAMUserResp)JsonUtils.parse(json, FilaHelper.IAMUserResp.class);
      System.out.println(iamUserResp.getClient_id());
   }


   public static class IAMTokenResp {

      private String access_token;
      private String refresh_token;
      private boolean success = false;
      private String scope;
      private String token_type;
      private String message;
      private Long expires_in;


      public String getAccess_token() {
         return this.access_token;
      }

      public void setAccess_token(String access_token) {
         this.access_token = access_token;
      }

      public String getRefresh_token() {
         return this.refresh_token;
      }

      public void setRefresh_token(String refresh_token) {
         this.refresh_token = refresh_token;
      }

      public boolean isSuccess() {
         return this.success;
      }

      public void setSuccess(boolean success) {
         this.success = success;
      }

      public String getScope() {
         return this.scope;
      }

      public void setScope(String scope) {
         this.scope = scope;
      }

      public String getToken_type() {
         return this.token_type;
      }

      public void setToken_type(String token_type) {
         this.token_type = token_type;
      }

      public String getMessage() {
         return this.message;
      }

      public void setMessage(String message) {
         this.message = message;
      }

      public Long getExpires_in() {
         return this.expires_in;
      }

      public void setExpires_in(Long expires_in) {
         this.expires_in = expires_in;
      }
   }

   public static class IAMUserAttribute {

      private String authenticationMethod;
      private String authenticationDate;
      @JsonIgnore
      private String credentialType;
      private String email;
      private String mobilephone;
      private String preEmail;
      private String employeeId;
      private String name;
      private String loginName;
      private String isFromNewLogin;
      private String longTermAuthenticationRequestTokenUsed;
      private String successfulAuthenticationHandlers;


      public String getAuthenticationDate() {
         return this.authenticationDate;
      }

      public void setAuthenticationDate(String authenticationDate) {
         this.authenticationDate = authenticationDate;
      }

      public String getCredentialType() {
         return this.credentialType;
      }

      public void setCredentialType(String credentialType) {
         this.credentialType = credentialType;
      }

      public String getEmail() {
         return this.email;
      }

      public void setEmail(String email) {
         this.email = email;
      }

      public String getEmployeeId() {
         return this.employeeId;
      }

      public void setEmployeeId(String employeeId) {
         this.employeeId = employeeId;
      }

      public String getName() {
         return this.name;
      }

      public void setName(String name) {
         this.name = name;
      }

      public String getLoginName() {
         return this.loginName;
      }

      public void setLoginName(String loginName) {
         this.loginName = loginName;
      }

      public String getIsFromNewLogin() {
         return this.isFromNewLogin;
      }

      public void setIsFromNewLogin(String isFromNewLogin) {
         this.isFromNewLogin = isFromNewLogin;
      }

      public String getLongTermAuthenticationRequestTokenUsed() {
         return this.longTermAuthenticationRequestTokenUsed;
      }

      public void setLongTermAuthenticationRequestTokenUsed(String longTermAuthenticationRequestTokenUsed) {
         this.longTermAuthenticationRequestTokenUsed = longTermAuthenticationRequestTokenUsed;
      }

      public String getSuccessfulAuthenticationHandlers() {
         return this.successfulAuthenticationHandlers;
      }

      public void setSuccessfulAuthenticationHandlers(String successfulAuthenticationHandlers) {
         this.successfulAuthenticationHandlers = successfulAuthenticationHandlers;
      }

      public String getAuthenticationMethod() {
         return this.authenticationMethod;
      }

      public void setAuthenticationMethod(String authenticationMethod) {
         this.authenticationMethod = authenticationMethod;
      }

      public String getMobilephone() {
         return this.mobilephone;
      }

      public void setMobilephone(String mobilephone) {
         this.mobilephone = mobilephone;
      }

      public String getPreEmail() {
         return this.preEmail;
      }

      public void setPreEmail(String preEmail) {
         this.preEmail = preEmail;
      }
   }

   public static class IAMUserResp {

      private String service;
      private FilaHelper.IAMUserAttribute attributes;
      private String id;
      private String client_id;


      public String getService() {
         return this.service;
      }

      public void setService(String service) {
         this.service = service;
      }

      public String getId() {
         return this.id;
      }

      public void setId(String id) {
         this.id = id;
      }

      public FilaHelper.IAMUserAttribute getAttributes() {
         return this.attributes;
      }

      public void setAttributes(FilaHelper.IAMUserAttribute attributes) {
         this.attributes = attributes;
      }

      public String getClient_id() {
         return this.client_id;
      }

      public void setClient_id(String client_id) {
         this.client_id = client_id;
      }
   }
}
